/****************************** HEADER *********************************
Larry Bednar, US Forest Service, Portland Forestry Sciences Lab,
         Portland, OR. (503) 808-2016.
PURPOSE: As a component of the TABLING application, this SAS program
         reads a SAS data set specified to contain subpopulation
         descriptions and outputs that data to the SAS data set used
         within the TABLING application to hold subpopulation data.

$RCSfile: get_sp.sas,v $; 
$Revision: 1.5 $; 
$Date: 2002/02/15 20:54:10 $;   
$Author: lbednar $; 
************************************************************************
/******************************* CODE **********************************/

%MACRO get_sp(gs_data_in  =,
              gs_id       =,
              gs_sz       =,
              gs_data_out =WORK.SUBPOP);

/***********************************************************************/
/* This macro requires user specification of the following variables:  */
/*  DATA_IN - indicates the SAS two-part data set specification for    */
/*            the data set containing the incoming data                */
/*  ID      - indicates the name of the SAS variable holding the       */
/*            stratum ID variable                                      */
/*  SIZE    - indicates the name of the SAS variable holding the       */
/*            subpopulation size, in numbers of sample units           */
/*  DATA_OUT- indicates the name of the SAS data set to which data     */
/*            will be written                                          */
/***********************************************************************/

    *Create the subpop data set used by the tabling application, rename
     variables to names expected by the application;
    DATA &gs_data_out (LABEL="Input subpop data");
       %IF &gs_sz =  %THEN
          %DO;
	     SET &gs_data_in (RENAME=(&gs_id   = sp));
	     LABEL sp = "subpop id";
	     KEEP sp;
          %END;
       %ELSE
          %DO;
	     SET &gs_data_in (RENAME=(&gs_id = sp
				      &gs_sz = sz_sp));
	     LABEL sp    = "subpop id"
		   sz_sp = "subpop size";
	     KEEP sp
		  sz_sp;
          %END;
    RUN;

    PROC CONTENTS DATA=&gs_data_out;
    RUN;

%MEND get_sp;


*** END OF MACRO ***;
*** END OF MACRO ***;
