/****************************** HEADER *********************************
Larry Bednar, US Forest Service, Portland Forestry Sciences Lab,
         Portland, OR. (503) 808-2016.
PURPOSE: As a component of the TABLING application, this SAS program
         reads a SAS data set specified to contain subpopulation
         descriptions and outputs that data to the SAS data set used
         within the TABLING application to hold subpopulation data.
         The macro is used for obtaining subpopulation information as
         obtained from simple random sample of each subpopuulation.

$RCSfile: get_sp_r.sas,v $; 
$Revision: 1.4 $; 
$Date: 2002/02/15 20:58:11 $;   
$Author: lbednar $; 
************************************************************************

/******************************* CODE **********************************/

%MACRO get_sp_r(gsr_data_in  =,
                gsr_id       =,
                gsr_sz       =,
                gsr_ssz      =,
                gsr_data_out =WORK.subpop);

/************************************************************************/
/* This macro requires user specification of the following variables:   */
/*  GSR_DATA_IN - indicates the SAS two-part data set specification for */
/*            the data set containing the incoming data                 */
/*  GSR_ID      - indicates the name of the SAS variable holding the    */
/*            stratum ID variable                                       */
/*  GSR_SZ      - indicates the name of the SAS variable holding the    */
/*            subpopulation size, in numbers of sample units            */
/*  GSR_SSZ     - indicates the name of the SAS variable holding the    */
/*            size of the simple random sample drawn from the subpop    */
/*  GSR_DATA_OUT- indicates the name of the SAS data set to which data  */
/*            will be written                                           */
/************************************************************************/

    %PUT "TABLING module GET_SP_R started";

    *Create the subpop data set used by the tabling application, rename
     variables to names expected by the application;
    DATA &gsr_data_out(LABEL="Input subpop data");
        SET &gsr_data_in(RENAME=(&gsr_id      =sp
                                 &gsr_sz      =sz_sp
                                 &gsr_ssz     =n));
        LABEL sp="subpop id"
              sz_sp="subpop size"
              n="subpop samp size";
        KEEP sp
             sz_sp
             n;
    RUN;

    PROC CONTENTS DATA=&gsr_data_out;
    RUN;

    %PUT "TABLING module GET_SP_R ended";

%MEND get_sp_r;


*** END OF MACRO ***;
*** END OF MACRO ***;
