/****************************** HEADER *********************************
Larry Bednar, US Forest Service, Portland Forestry Sciences Lab,
         Portland, OR. (503) 808-2016.
PURPOSE: As a component of the TABLING application, this SAS program
         reads a SAS data set specified to contain stratum
         descriptions and outputs that data to the SAS data set used
         within the TABLING application to hold stratum data.  The
         macro assumes a double sampling approach, and therefore
         expects both a primary and secondary sample size for each
         stratu.

$RCSfile: get_st_d.sas,v $; 
$Revision: 1.1 $; 
$Date: 2000/02/23 00:25:07 $;   
$Author: lbednar $; 
************************************************************************

/******************************* CODE **********************************/

%macro get_st_d(data_in=,
                sp=,
                id=,
                size1=,
                size=,
                data_out=WORK.STRATA);

/***********************************************************************/
/* This macro requires user specification of the following variables:  */
/*  DATA_IN - indicates the SAS two-part data set specification for    */
/*            the data set containing the incoming data                */
/*  SP      - indicates the name of the SAS variable holding the       */
/*            subpopulation ID variable                                */
/*  ID      - indicates the name of the SAS variable holding the       */
/*            stratum ID variable                                      */
/*  SIZE1   - indicates the name of the SAS variable holding the       */
/*            stratum primary sample size, in numbers of sample units  */
/*  SIZE    - indicates the name of the SAS variable holding the       */
/*            stratum secondary sample size, in numbers of sample units*/
/*  DATA_OUT- indicates the name of the SAS data set to which data     */
/*            will be written                                          */
/***********************************************************************/

    *Create the stratum data set used by the tabling application, rename
     variables to names expected by the application;
    DATA &data_out(LABEL="Input stratum data");
        SET &data_in(RENAME=(&sp=sp
                             &id=h
                             &size1=n1_h
                             &size=n_h));
        LABEL sp="subpop id"
              h="stratum id"
              n1_h="stratum prim samp size"
              n_h="stratum secdry samp size";
        KEEP sp
             h
             n1_h
             n_h;
    RUN;

%MEND get_st_d;


*** END OF MACRO ***;
*** END OF MACRO ***;
