/****************************** HEADER *********************************
Larry Bednar, US Forest Service, Portland Forestry Sciences Lab,
         Portland, OR. (503) 808-2016.
PURPOSE: As a component of the TABLING application, this SAS program
         reads a SAS data set specified to contain stratum
         descriptions and outputs that data to the SAS data set used
         within the TABLING application to hold stratum data. The
         macro assumes a simple stratified random sampling approach is
         being used.

$RCSfile: get_st_s.sas,v $; 
$Revision: 1.8 $; 
$Date: 2002/02/15 21:05:20 $;   
$Author: lbednar $; 
************************************************************************

******************************* CODE **********************************/

%macro get_st_s(gss_data_in  =,
                gss_sp       =,
                gss_id       =,
                gss_sz       =,
                gss_ssz      =,
                gss_ssz1     =,
                gss_data_out =WORK.stratum);

***********************************************************************;
* This macro requires user specification of the following variables:  *;
*  DATA_IN - indicates the SAS two-part data set specification for    *;
*            the data set containing the incoming data                *;
*  SP      - indicates the name of the SAS variable holding the       *;
*            subpopulation ID variable                                *;
*  ID      - indicates the name of the SAS variable holding the       *;
*            stratum ID variable                                      *;
*  SZ      - indicates the name of the SAS variable hodling the       *;
*            stratum size, in numbers of sample units                 *;
*  SSZ     - indicates the name of the SAS variable holding the       *;
*            stratum sample size                                      *;
*  SSZ1    - indicates the name of the SAS variable holding the      *;
*            stratum primary sample size                              *;
*  DATA_OUT- indicates the name of the SAS data set to which data     *;
*            will be written                                          *;
***********************************************************************;

    %LOCAL gss_ssz1_keep
           gss_ssz1_label
           gss_ssz1_rename
           gss_sz_keep
           gss_sz_label
           gss_sz_rename;

    %*Set text strings needed to construct statements to handle GSS_SZ  
      value;
    %LET gss_sz_rename = ;
    %LET gss_sz_label  = ;
    %LET gss_sz_keep   = ;
    %IF &gss_sz   ^=  %THEN 
       %DO;
          %LET gss_sz_keep   = sz_h;
	  %LET gss_sz_label  = %QUOTE(sz_h = "sample size");
	  %IF %UPCASE(&gss_sz  ) ^= SZ_H  %THEN
	     %LET gss_sz_rename = %QUOTE(&gss_sz   = sz_h);
       %END;
    %PUT GSS_SZ_RENAME is "&gss_sz_rename";
    %PUT GSS_SZ_LABEL  is "&gss_sz_label";

    %*Set text strings needed to construct statements to handle GSS_SSZ1
      value;
    %LET gss_ssz1_rename = ;
    %LET gss_ssz1_label  = ;
    %LET gss_ssz1_keep   = ;
    %IF &gss_ssz1 ^=  %THEN 
       %DO;
          %LET gss_ssz1_keep   = n1_h;
	  %LET gss_ssz1_label  = %QUOTE(n1_h = "primary sample size");
	  %IF %UPCASE(&gss_ssz1) ^= N1_H  %THEN
	     %LET gss_ssz1_rename = %QUOTE(&gss_ssz1 = n1_h);
       %END;
    %PUT GSS_SSZ1_RENAME is "&gss_ssz1_rename";
    %PUT GSS_SSZ1_LABEL  is "&gss_ssz1_label";

    *Create the stratum data set used by the tabling application, rename
     variables to names expected by the application;
    DATA &gss_data_out         (LABEL ="Input stratum data");
	SET &gss_data_in (RENAME=(&gss_sp      = sp
				  &gss_id      = h
				  &gss_sz_rename
				  &gss_ssz    = n_h
				  &gss_ssz1_rename ));
	LABEL sp   = "subpop id"
	      h    = "stratum id"
	      &gss_sz_label
	      n_h  = "stratum samp size"
	      &gss_ssz1_label;
	KEEP sp
	     h
	     &gss_sz_keep
	     n_h
             &gss_ssz1_keep;
    RUN;

    PROC CONTENTS DATA=&gss_data_out;
    RUN;

%MEND get_st_s;


*** END OF MACRO ***;
*** END OF MACRO ***;
