/****************************** HEADER *********************************
Larry Bednar, US Forest Service, Portland Forestry Sciences Lab,
         Portland, OR. (503) 808-2016.
PURPOSE: In the TABLING application, this SAS program defines the macro
         responsible for checking job specifications provided by the
         user to ensure that no gross specification errors are present;

$RCSfile: in_chk.sas,v $; 
$Revision: 1.4 $; 
$Date: 2002/01/26 20:58:55 $;   
$Author: lbednar $; 
************************************************************************/

%*This utility macro is used within the IN_CHK macro to determine
  whether a macro variable has been assigned a value;
%MACRO symchk(sc_name);
   %IF %NRQUOTE(&&&sc_name)=%NRSTR(&)&sc_name %THEN
      %LET sc_value = NO;
   %ELSE
      %LET sc_value = YES;
   &sc_value
%MEND symchk;

%PUT "SYMCHK result is %symchk(test_dir)";

%*This macro is used within the IN_CHK macro to verify that specified
  variables are of a specific data type;
%MACRO chktype(ct_lib    =,
               ct_dset   =,
               ct_var_in =,
               ct_vtype  =NUMBER);

   %LET ct_corrtype = NO;
   PROC CONTENTS
      DATA = &ct_lib..&ct_dset
      OUT  = work.m_dvars (KEEP=name type)
      NOPRINT;
   RUN;
   %LET ct_present = NO;
   DATA work.m_dvars2;
      SET work.m_dvars;
      name_in = "&var_in";
      IF UPCASE(name)=UPCASE("&var_in") THEN
         DO;
            SELECT ("&ct_vtype");
               WHEN ("NUMBER")     IF type=1 THEN CALL SYMPUT('ic_corrtype','YES');
               WHEN ("CHARACTER")  IF type=1 THEN CALL SYMPUT('ic_corrtype','YES');
               OTHERWISE;
            END;
            STOP;
         END;
   PROC DATASETS LIBRARY=work;
      DELETE m_dvars 
             m_dvars2;
   RUN;
%MEND chktype;

%*This macro is used within the IN_CHK macro to verify that specified
  variables are members of the data sets specified;
%MACRO chkvar(cv_lib   =,
              cv_dset  =,
              cv_var_in=);

   %LET ic_present = NO;
   PROC CONTENTS
      DATA = &cv_lib..&cv_dset
      OUT  = work.m_dvars (KEEP=name type)
      NOPRINT;
   RUN;
   %LET cv_present = NO;
   DATA work.m_dvars2;
      SET work.m_dvars;
      name_in="&cv_var_in";
      IF UPCASE(name)=UPCASE("&cv_var_in") THEN
         DO;
            CALL SYMPUT('ic_present','YES');
            STOP;
         END;
   PROC DATASETS LIBRARY=work;
      DELETE m_dvars 
             m_dvars2;
   RUN;
%MEND chkvar;

%MACRO dset_exists(de_dset, de_resp_var);
%*This macro is used used within the IN_CHK macro to test for the existance
  of the user-specified SAS data sets. The macro sets the variable macro
  variable specified in "de_resp_var" to YES if data set indicated by "de_dset"
  exists, NO otherwise;

   %IF &de_dset NE  %THEN
      %DO;
         DATA _NULL_;
            IF 0 THEN SET &de_dset;
            STOP;
         RUN;
         %IF &SYSERR=0 %THEN %LET &de_resp_var = YES;
         %ELSE               %LET &de_resp_var = NO;
      %END;

%MEND dset_exists;

%*This macro is used to set the macro response;
%MACRO set_response (sr_var, sr_resp);
   %LET &sr_resp = %UPCASE(&sr_resp);
   %IF &sr_resp = ERROR   %THEN %LET &sr_var = &sr_resp;
   %IF &sr_resp = WARNING %THEN
      %DO;
         %*WARNING never overwrites a preexisting ERROR response;
         %IF &sr_var = ERROR %THEN %LET &sr_var = &sr_var;
         %ELSE                     %LET &sr_var = &sr_resp;
      %END;
%MEND set_response;

%MACRO in_chk(ic_title   =,
              ic_title2  =,
              ic_method  =,
              ic_est_stat=,
              ic_sp      =,
              ic_sp_spid =,
              ic_sp_sz   =,
              ic_sp_ssz  =,
              ic_st      =,
              ic_st_spid =,
              ic_st_stid =,
              ic_st_sz   =,
              ic_st_ssz1 =,
              ic_st_ssz  =,
              ic_su      =,
              ic_su_spid =,
              ic_su_stid =,
              ic_su_suid =,
              ic_su_rows =,
              ic_su_cols =,
              ic_su_attr =,
              ic_unit    =,
              ic_sig     =,
              ic_margins =,
              ic_print   =,
              ic_libout  =,
              ic_dataout =,
              ic_htmlout =);

   ***********************************************************************;
   * This macro assumes nothing about the referencing environment calling ;
   * this macro.  All output is provided by returned text or SAS LOG      ;
   * output.  All input to this macro is provided by explicity passing of ;
   * macro variable values at macro invocation.                           ;
   ***********************************************************************;

   %LET &ic_method   = %UPCASE(&ic_method);
   %LET &ic_est_stat = %UPCASE(&ic_est_stat);
   %LET &ic_margins  = %UPCASE(&ic_margins);
   %LET &ic_print    = %UPCASE(&ic_print);

   %*Define variables used to pass specification checking results from 
     subsidiary utility macros;
     IN_CHK;
   %LET ic_corrtype    = NO;
   %LET ic_present     = NO;
   %LET ic_dset_exists = NO;

   %IF "&ic_method" ^= "DOUBLE" AND
       "&ic_method" ^= "STRAT"  AND
       "&ic_method" ^= "RANDOM" AND
       "&ic_method" ^= "CENSUS" %THEN
      %DO;
         %set_response(ic_response,ERROR);
         %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
         %PUT "   specification for METHOD must be DOUBLE, STRAT, RANDOM or CENSUS";
      %END;

   %IF (&ic_method    = DOUBLE  OR
        &ic_method    = STRAT   OR
        &ic_method    = RANDOM       ) AND
       (&ic_est_stat ^= MEAN    AND
        &ic_est_stat ^= SUM     AND
        &ic_est_stat ^= RATIO_S      ) %THEN
      %DO;
         %set_response(ic_response,ERROR);
         %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
         %PUT "   EST_STAT must have value MEAN, SUM or RATIO_S for specified METHOD";
      %END;
   %IF (&ic_method   =CENSUS       ) AND
       (&ic_est_stat^=MEAN    AND
        &ic_est_stat^=SUM          ) %THEN
      %DO;
         %set_response(ic_response,ERROR);
         %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
         %PUT "   EST_STAT must have value MEAN or SUM specified CENSUS method";
      %END;

   %IF &ic_method              =ROM_S  AND
       %SCAN(&ic_su_attr,2,/)  =         %THEN
      %DO;
         %set_response(ic_response,ERROR);
         %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
         %PUT "   RATIO_S method requires specification of two variables in SU_ATTR value";
      %END;
 
   %IF &ic_method             ^=ROM_S  AND
       %SCAN(&ic_su_attr,2,/) ^=         %THEN
      %DO;
         %set_response(ic_response,WARNING);
         %PUT "TABLING PGM JOB SPECIFICATION WARNING:";
         %PUT "   unless method is ROM_S, only one variable in SU_ATTR value is used";
      %END;
 
   %IF &ic_margins ^=     AND
       &ic_margins ^=YES  AND
       &ic_margins ^=N0   %THEN
      %DO;
         %set_response(ic_response,WARNING);
         %PUT "TABLING PGM JOB SPECIFICATION WARNING:";
         %PUT "   Any value for MARGINS which is not 'YES' is interpreted as 'NO'";
      %END;
 
   %IF &ic_print ^=     AND
       &ic_print ^=YES  AND
       &ic_print ^=N0   %THEN
      %DO;
         %set_response(ic_response,WARNING);
         %PUT "TABLING PGM JOB SPECIFICATION WARNING:";
         %PUT "   Any value for PRINT which is not 'YES' is interpreted as 'NO'";
      %END;

   %*Check specification of subpop data set;
   %IF (&ic_method=DOUBLE OR
        &ic_method=STRAT  OR
        &ic_method=RANDOM    ) %THEN
      %DO;

         %dset_exists(&ic_sp, ic_dset_exists);
         %IF &ic_dset_exists = NO %THEN
            %DO;
               %set_response(ic_response,ERROR);
               %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
               %PUT "   specified subpop data set does not exist";

            %END;
         %ELSE
            %DO; 

               %chkvar(&ic_sp,&ic_sp_spid)
               %IF &ic_present^=YES %THEN
                  %DO;
                     %set_response(ic_response,ERROR);
                     %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                     %PUT "   the specified subpop ID var was not found on the subpop data set";
                  %END;

               %chkvar(&ic_sp,&ic_sp_sz)
               %IF &ic_present^=YES %THEN
                  %DO;
                     %set_response(ic_response,ERROR);
                     %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                     %PUT "   the specified subpop size var was not found on the subpop data set";
                  %END;
               %ELSE
                  %DO;
                     %chktype(&ic_sp,&ic_sp_sz)
                     %IF &ic_corrtype^=YES %THEN
                        %DO;
                           %set_response(ic_response,ERROR);
                           %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                           %PUT "   the specified subpop size var must a numeric var";
                        %END;
                  %END;

            %*Check specification of subpop sample size;
            %IF (&ic_method=RANDOM   ) %THEN
               %DO;

                  %chkvar(&ic_sp,&ic_sp_ssz)
                  %IF &ic_present^=YES %THEN
                      %DO;
                         %set_response(ic_response,ERROR);
                         %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                         %PUT "   the specified subpop sample size var was not found on the subpop data set";
                      %END;
                     %END;

               %END;

            %END;  %*End of subpop dset exists do bloc;

      %END;  %* end of subpop dset check;


   %*Check specification of stratum data set;
   %IF &ic_method=DOUBLE OR
       &ic_method=STRAT      %THEN
      %DO;

         %dset_exists(&ic_st, ic_dset_exists);
         %IF &ic_dset_exists = NO %THEN
            %DO;
               %set_response(ic_response,ERROR);
               %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
               %PUT "   the specified stratum data set does not exist";
            %END;
         %ELSE
            %DO;

               chkvar(&ic_st,&ic_st_spid)
               %IF &ic_present^=YES %THEN
                  %DO;
                     %set_response(ic_response,ERROR);
                     %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                     %PUT "   the specified subpop ID var was not found on the stratum data set";
                  %END;

               %chkvar(&ic_st,&ic_st_stid)
               %IF &ic_present^=YES %THEN
                  %DO;
                     %set_response(ic_response,ERROR);
                     %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                     %PUT "   the specified stratum ID variable was not found on the stratum data set";
                  %END;

               %chkvar(&ic_st,&ic_st_sz)
               %IF &ic_present^=YES %THEN
                  %DO;
                     %set_response(ic_response,ERROR);
                     %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                     %PUT "   the specified stratum size var was not found on the stratum data set";
                  %END;
               %ELSE
                  %DO;
                     %*If present, check variable for correct type;
                     %chktype(&ic_st,&ic_st_sz)
                     %IF &ic_corrtype^=YES %THEN
                        %DO;
                           %set_response(ic_response,ERROR);
                           %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                           %PUT "   the specified stratum size var must a numeric var ";
                        %END;
                  %END;

               %chkvar(&ic_st,&ic_st_ssz)
               %IF &ic_present^=YES %THEN
                  %DO;
                     %set_response(ic_response,ERROR);
                     %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                     %PUT "   the specified stratum sample size variable was not found on the stratum data set";
                  %END;
               %ELSE
                  %DO;
                     %*If present, check variable for correct type;
                     %chktype(&ic_st,&ic_st_ssz)
                     %IF &ic_corrtype^=YES %THEN
                        %DO;
                           %set_response(ic_response,ERROR);
                           %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                           %PUT "   the specified stratum sample size var must a numeric var ";
                        %END;
                  %END;

            %END;

      %END;

   %IF &ic_method=DOUBLE %THEN
      %DO;

         %IF %symck(&ic_st_ssz1)=NO %THEN
            %DO;
               %set_response(ic_response,ERROR);
               %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
               %PUT "   a stratum primary sample size var must be specified on the stratum data set";
            %END;
         %ELSE
            %DO;
               %chktype(&ic_st,&ic_st_ssz1)
               %IF &ic_corrtype^=YES %THEN
                  %DO;
                     %set_response(ic_response,ERROR);
                     %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                     %PUT "   the specified stratum primary sample size var must a numeric var ";
                  %END;
            %END;

      %END;

   %IF &ic_method=CENSUS OR
       &ic_method=STRAT  OR
       &ic_method=DOUBLE     %THEN
      %DO;

         %IF %symck(&ic_sp_ssz)=YES %THEN
            %DO;
               %chkvar(&ic_sp_ssz)
               %IF &ic_present^=YES %THEN
                  %DO;
                     %set_response(ic_response,WARNING);
                     %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                     %PUT "   subpop sample size var not needed for CENSUS, STRAT, DOUBLE methods";
                  %END;
            %END;

      %END;

   %IF &ic_method=STRAT %THEN
      %DO;

         %chkvar(&ic_st_ssz1)
         %IF &ic_present^=YES %THEN
            %DO;
               %set_response(ic_response,WARNING);
               %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
               %PUT "   stratum primary sample size var not needed for STRAT method";
            %END;

      %END;

   %IF &ic_method=CENSUS OR
       &ic_method=RANDOM    %THEN
      %DO;

         %IF %symck(&ic_su)=YES %THEN
            %DO;
               %chkvar(&ic_su_stid)
               %IF &ic_present^=YES %THEN
                  %DO;
                     %set_response(ic_response,WARNING);
                     %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                     %PUT "   sample unit stratum id var not needed for CENSUS, RANDOM methods";
                  %END;
            %END;

         %IF %symck(&ic_st)=YES %THEN
            %DO;
               %set_response(ic_response,WARNING);
               %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
               %PUT "   stratum data set not needed for CENSUS, RANDOM methods";
            %END;

      %END;

   %dset_exists(&ic_su, ic_dset_exists);
   %IF &ic_dset_exists = NO %THEN
      %DO;
         %set_response(ic_response,ERROR);
         %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
         %PUT "   specified observation data set does not exist";
      %END;
   %ELSE
      %DO;

         %chkvar(&ic_su_suid)
         %IF &ic_present^=YES  %THEN
            %DO;
            %set_response(ic_response,ERROR);
            %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
            %PUT "   the specified sample unit ID var was not found on the obs data set";
         %END;

         %chkvar(%SCAN(&ic_su_attr,1,/))
         %IF &ic_present^=YES  %THEN
            %DO;
               %set_response(ic_response,ERROR);
               %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
               %PUT "   the specified sample unit analysis var was not found on the obs data set";
            %END;
         %ELSE
            %DO;
               %chktype(&ic_su,&ic_su_attr)
               %IF &corrtype^=YES %THEN
                  %DO;
                     %set_response(ic_response,ERROR);
                     %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                     %PUT "   the specified analysis var must be a numeric var ";
                  %END;
            %END;

         %IF (%SCAN(&ic_su_attr,2,/) ^=           AND
              &ic_est_stat            =ROM_S )  %THEN
            %DO;
               %chkvar(%SCAN(&ic_su_attr,2,/))
               %IF &ic_present^=YES  %THEN
                  %DO;
                     %set_response(ic_response,ERROR);
                     %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                     %PUT "   the 2d specified analysis var was not found on the obs data set";
                  %END;
               %ELSE
                  %DO;
                     %chktype(&ic_su,%SCAN(&ic_su_attr,2,/))
                     %IF &corrtype^=YES %THEN
                        %DO;
                           %set_response(ic_response,ERROR);
                           %PUT "TABLING PGM JOB SPECIFICATION ERROR:";
                           %PUT "   the 2d specified analysis var must be a numeric var ";
                        %END;
                  %END;
            %END;

      %END;

%PUT "Macro IN_CHK compilation completed";

%*&ic_response;

%MEND in_chk;

**END OF MACRO;
**END OF MACRO;

