/****************************** HEADER *********************************
Larry Bednar, US Forest Service, Portland Forestry Sciences Lab,
         Portland, OR. (503) 808-2016.
PURPOSE: These SAS statements define the a macro used to round values
         of user-specified SAS variables to a specified number of
         significant digits;

$RCSfile: sig_figs.sas,v $; 
$Revision: 1.2 $; 
$Date: 2002/01/31 19:11:27 $;   
$Author: lbednar $; 
************************************************************************/

%MACRO sig_figs(sf_data_in  =,
                sf_chg_vars =,
                sf_digits   =);

   *********************************************************************;
   * This macro changes the values of variables indicated by the        ;
   * user to display the number of significant digits indicated.        ;
   * Up to 5 variables may be specified for conversion                  ;
   * The following values must be provided at macro invocation:         ;
   * DATA_IN  - full name of target dataset                             ;
   * CHG_VARS - space-delimited list of variables to be converted       ;
   * DIGITS   - number of significant digits desired                    ;
   *********************************************************************;

   %LOCAL sf_chg1
	  sf_chg2
	  sf_chg3
	  sf_chg4
	  sf_chg5
	  sf_i;

   %*Break specified variable list into words;
      %LET sf_i = 1;
      %DO %WHILE( &sf_i < 5 );
	 %LET sf_chg&sf_i = %SCAN(&sf_chg_vars, &sf_i);
	 %LET sf_i =%EVAL( &sf_i + 1 );
      %END;

   %*Convert final estimates to appropriate number of significant digits;
   DATA &sf_data_in;
      SET &sf_data_in;
      sig_dgt = &sf_digits;
      %LET sf_i = 1;
      %DO %WHILE( &sf_i < 5 );
      %IF &&&sf_chg&sf_i ^=  %THEN
	 %DO;
	    IF &&&sf_chg&sf_i ^= 0 THEN
	       &&&sf_chg&sf_i  = ROUND(&&&sf_chg&sf_i,
				       10 ** FLOOR(LOG10(ABS( &&&sf_chg&sf_i ))- sig_dgt +1 ));
	 %END;
	 %LET sf_i = %EVAL( &sf_i + 1 );
      %END;
      DROP sig_dgt;
   RUN;

%MEND sig_figs;

*** END OF MACRO ***;
*** END OF MACRO ***;

