/****************************** HEADER *********************************
Larry Bednar, US Forest Service, Portland Forestry Sciences Lab,
         Portland, OR. (503) 808-2016.
PURPOSE: These SAS statements define the main macro used to control
         execution of computational sections of the PRIME Table
         Report Application.;

$RCSfile: tabling.sas,v $
$Revision: 1.23 $
$Date: 2002/02/20 01:43:40 $
$Author: lbednar $
************************************************************************/
OPTIONS PAGESIZE=53 LINESIZE=90 PAGENO=1 NUMBER NODATE
        NOMPRINT NOSYMBOLGEN;
*GOPTIONS RESET=ALL DEVICE=WIN TARGETDEVICE=HPLJ3SI ROTATE=LANDSCAPE;

/******************************* CODE **********************************/

%*Set directory that tabling application files reside in;
   %*LET tab_dir=\\prime2\tools\applications\tabling\program;
   %LET tab_dir=d:\work\prof\tricision_tabling_rom\work\tabling_mod\source_code;


%*Compile data retrieval macros;
   %INCLUDE "&tab_dir\get_sp.sas";
   %INCLUDE "&tab_dir\get_sp_r.sas";
   %*INCLUDE "&tab_dir\get_st_d.sas";
   %INCLUDE "&tab_dir\get_st_s.sas";
   %INCLUDE "&tab_dir\get_ob_s.sas";
   %INCLUDE "&tab_dir\get_ob.sas";

%*Compile estimation macros;
   %INCLUDE "&tab_dir\double.sas";
   %INCLUDE "&tab_dir\strat.sas";
   %INCLUDE "&tab_dir\random.sas";
   %INCLUDE "&tab_dir\census.sas";
   %INCLUDE "&tab_dir\double_rs.sas";
   %INCLUDE "&tab_dir\strat_rs.sas";
   %INCLUDE "&tab_dir\random_rs.sas";

%*Compile reporting macro;
   %INCLUDE "&tab_dir\repout.sas";

%*Compile specification error checking macro;
   %INCLUDE "&tab_dir\in_chk.sas";

%*Compile utility macros;
   %INCLUDE "&tab_dir\chg_blnk.sas";
   %INCLUDE "&tab_dir\sig_figs.sas";

%MACRO rcskval(val);
   %*This macro returns only the value from an RCS keyword/value pair;
   %LOCAL start len val2 valout;
   %LET val2  =%STR(&val);
   %LET start =%EVAL( %INDEX(&val2,: ) + 2 );
   %LET len   =%EVAL( %LENGTH(&val2) - &start );
   %LET valout=%SUBSTR(&val2,&start,&len);
   &valout
%MEND;

%MACRO tabling(t_title   =PNW FIA Population Estimates,
               t_title2  =,
               t_method  =DOUBLE,
               t_est_stat=SUM,
               t_sp      =,
               t_sp_spid =,
               t_sp_sz   =,
               t_sp_ssz  =,
               t_st      =,
               t_st_spid =,
               t_st_stid =,
               t_st_sz   =,
               t_st_ssz1 =,
               t_st_ssz  =,
               t_su      =,
               t_su_spid =,
               t_su_stid =,
               t_su_suid =,
               t_su_rows =,
               t_su_cols =,
               t_su_attr =,
               t_unit    =1,
               t_sig     =3,
               t_margins =NO,
               t_print   =YES,
               t_libout  =,
               t_dataout =,
               t_htmlout =);

OPTIONS MPRINT NOSYMBOLGEN;

%LET Program=%rcskval(%STR($RCSfile: tabling.sas,v $));
%LET Version=%rcskval(%STR($Revision: 1.23 $));
%LET Coder  =%rcskval(%STR($Author: lbednar $));

FOOTNOTE
"&Program &Version - &Coder - &sysscp SAS V&sysver -(&sysdate,&systime)";

%LET t_method  =%UPCASE(&t_method);
%LET t_est_stat=%UPCASE(&t_est_stat);
%LET t_print   =%UPCASE(&t_print);
%LET t_margins =%UPCASE(&t_margins);

TITLE  "&t_title";
TITLE2 "&t_title2";

%LOCAL t_su_attr_denom
       t_denom_desc_txt
       t_in_chk_result;

*Delete preexisting versions of data set holding final estimates;
PROC DATASETS LIBRARY=WORK;
    DELETE m_final;
RUN;

%*Run job specification error checking macro;
%in_chk(ic_title   =&t_title,  
        ic_title2  =&t_title2,
        ic_method  =&t_method, 
        ic_est_stat=&t_est_stat,
        ic_sp      =&t_sp,
        ic_sp_spid =&t_sp_spid,
        ic_sp_sz   =&t_sp_sz,
        ic_sp_ssz  =&t_sp_ssz,
        ic_st      =&t_st,
        ic_st_spid =&t_st_spid,
        ic_st_stid =&t_st_stid,
        ic_st_sz   =&t_st_sz,
        ic_st_ssz1 =&t_st_ssz1,
        ic_st_ssz  =&t_st_ssz,
        ic_su      =&t_su,
        ic_su_spid =&t_su_spid,
        ic_su_stid =&t_su_stid,
        ic_su_suid =&t_su_suid,
        ic_su_rows =&t_su_rows,
        ic_su_cols =&t_su_cols,
        ic_su_attr =&t_su_attr,
        ic_unit    =&t_unit,
        ic_sig     =&t_sig,
        ic_margins =&t_margins,
        ic_print   =&t_print,
        ic_libout  =&t_libout,
        ic_dataout =&t_dataout,
        ic_htmlout =&t_htmlout,
        ic_var_out =t_in_chk_result);

%*If IN_CHK macro returns an error abort the run;
%IF &t_in_chk_result = ERROR %THEN %GOTO err_end;

%*Separate 1st and 2d variables specified in value of T_SU_ATTR - for 
  use in ratio estimators;
%IF    &t_est_stat = ROM_S 
    OR &t_est_stat = ROM_C %THEN
   %DO; 
      %LET t_su_attr_denom  = %SCAN(&t_su_attr,2,/);
      %LET t_denom_desc_txt = /&t_su_attr_denom;
   %END;
%ELSE
   %LET t_su_attr_denom = ;
%LET    t_su_attr       = %SCAN(&t_su_attr,1,/);

%*Execute the proper SAS computation macro for the method specified;
%IF &t_method = CENSUS  %THEN
   %DO;
      %census(c_est_stat =&t_est_stat,
	      c_sp       =&t_sp,
	      c_sp_spid  =&t_sp_spid,
	      c_sp_sz    =&t_sp_sz,
	      c_su       =&t_su,
	      c_su_spid  =&t_su_spid,
	      c_su_suid  =&t_su_suid,
	      c_su_rows  =&t_su_rows,
	      c_su_cols  =&t_su_cols,
	      c_su_attr  =&t_su_attr,
	      c_unit     =&t_unit,
	      c_margins  =&t_margins );
   %END;
%IF &t_method = RANDOM  %THEN
   %DO;
      %PUT Block for METHOD = (&t_method) in (RANDOM) entered;
      %IF &t_est_stat = MEAN   OR
          &t_est_stat = SUM        %THEN
         %DO;
            %PUT Block for STAT (=&t_est_stat) in (MEAN,SUM) entered;
	    %random(r_est_stat      =&t_est_stat,
		    r_sp            =&t_sp,
		    r_sp_spid       =&t_sp_spid,
		    r_sp_sz         =&t_sp_sz,
		    r_sp_ssz        =&t_sp_ssz,
		    r_su            =&t_su,
                    r_su_spid       =&t_su_spid,
                    r_su_suid       =&t_su_suid,
		    r_su_rows       =&t_su_rows,
		    r_su_cols       =&t_su_cols,
		    r_su_attr       =&t_su_attr,
		    r_unit          =&t_unit,
		    r_margins       =&t_margins);
         %END;
      %IF &t_est_stat = ROM_S      %THEN
         %DO;
            %PUT Block for STAT (=&t_est_stat) in (ROM_S) entered;
	    %random_rs(rrs_est_stat      =&t_est_stat,
		       rrs_sp            =&t_sp,
		       rrs_sp_spid       =&t_sp_spid,
		       rrs_sp_sz         =&t_sp_sz,
		       rrs_sp_ssz        =&t_sp_ssz,
		       rrs_su            =&t_su,
                       rrs_su_spid       =&t_su_spid,
                       rrs_su_suid       =&t_su_suid,
		       rrs_su_rows       =&t_su_rows,
		       rrs_su_cols       =&t_su_cols,
		       rrs_su_attr       =&t_su_attr,
		       rrs_su_attr_denom =&t_su_attr_denom,
		       rrs_unit          =&t_unit,
		       rrs_margins       =&t_margins);
         %END;
   %END;
%IF &t_method = STRAT  %THEN
   %DO;
      %PUT Block for METHOD = (&t_method) in (STRAT) entered;
      %IF &t_est_stat = MEAN   OR
          &t_est_stat = SUM        %THEN
         %DO;
            %PUT Block for STAT (=&t_est_stat) in (MEAN,SUM) entered;
	    %strat( s_est_stat =&t_est_stat,
		    s_st       =&t_st,
		    s_st_spid  =&t_st_spid,
		    s_st_stid  =&t_st_stid,
		    s_st_ssz   =&t_st_ssz,
		    s_st_sz    =&t_st_sz,
		    s_su       =&t_su,
		    s_su_suid  =&t_su_suid,
		    s_su_stid  =&t_su_stid,
		    s_su_rows  =&t_su_rows,
		    s_su_cols  =&t_su_cols,
		    s_su_attr  =&t_su_attr,
		    s_unit     =&t_unit,
		    s_margins  =&t_margins);
         %END;
      %IF &t_est_stat = ROM_S  OR
          &t_est_stat = ROM_C     %THEN
         %DO;
            %PUT Block for STAT (=&t_est_stat) in (ROM_S,ROM_C) entered;
	    %strat_rs( srs_est_stat      =&t_est_stat,
		       srs_st            =&t_st,
		       srs_st_spid       =&t_st_spid,
		       srs_st_stid       =&t_st_stid,
		       srs_st_ssz        =&t_st_ssz,
		       srs_st_sz         =&t_st_sz,
		       srs_su            =&t_su,
		       srs_su_suid       =&t_su_suid,
		       srs_su_stid       =&t_su_stid,
		       srs_su_rows       =&t_su_rows,
		       srs_su_cols       =&t_su_cols,
		       srs_su_attr       =&t_su_attr,
		       srs_su_attr_denom =&t_su_attr_denom,
		       srs_unit          =&t_unit,
		       srs_margins       =&t_margins);
         %END;
   %END;
%IF &t_method = DOUBLE  %THEN
   %DO;
      %PUT Block for METHOD = (&t_method) in (DOUBLE) entered;
      %IF &t_est_stat = MEAN   OR
          &t_est_stat = SUM        %THEN
         %DO;
            %PUT Block for STAT (=&t_est_stat) in (MEAN,SUM) entered;
	    %double( d_est_stat      =&t_est_stat,
		     d_st            =&t_st,
		     d_st_spid       =&t_st_spid,
		     d_st_stid       =&t_st_stid,
		     d_st_ssz        =&t_st_ssz,
		     d_st_ssz1       =&t_st_ssz1,
		     d_st_sz         =&t_st_sz,
		     d_su            =&t_su,
		     d_su_suid       =&t_su_suid,
		     d_su_stid       =&t_su_stid,
		     d_su_rows       =&t_su_rows,
		     d_su_cols       =&t_su_cols,
		     d_su_attr       =&t_su_attr,
		     d_unit          =&t_unit,
		     d_margins       =&t_margins);
         %END;
      %IF &t_est_stat = ROM_S OR
          &t_est_stat = ROM_C    %THEN
         %DO;
            %PUT Block for STAT (=&t_est_stat) in (ROM_S,ROM_C) entered;
	    %double_rs( drs_est_stat      =&t_est_stat,
			drs_st            =&t_st,
			drs_st_spid       =&t_st_spid,
			drs_st_stid       =&t_st_stid,
			drs_st_ssz        =&t_st_ssz,
			drs_st_ssz1       =&t_st_ssz1,
			drs_st_sz         =&t_st_sz,
			drs_su            =&t_su,
			drs_su_suid       =&t_su_suid,
			drs_su_stid       =&t_su_stid,
			drs_su_rows       =&t_su_rows,
			drs_su_cols       =&t_su_cols,
			drs_su_attr       =&t_su_attr,
			drs_su_attr_denom =&t_su_attr_denom,
			drs_unit          =&t_unit,
			drs_margins       =&t_margins);
         %END;
   %END;

%*Convert final estimates to appropriate number of significant digits;
%sig_figs(sf_data_in  =WORK.m_final,
          sf_chg_vars =&t_est_stat v_&t_est_stat sd_&t_est_stat,
          sf_digits   =&t_sig)

%*Write final data to specified output data set;
%IF &t_libout  ^=   AND
    &t_dataout ^=       %THEN
   %DO;
      DATA &t_libout..&t_dataout;
          SET m_final;
      RUN;
   %END;

%IF %UPCASE(&t_print)=YES %THEN
   %DO;
      %repout(r2_method        =&t_method,
	      r2_est_stat      =&t_est_stat,
	      r2_rows          =&t_su_rows,
	      r2_cols          =&t_su_cols,
	      r2_su_attr       =&t_su_attr,
	      r2_su_attr_denom =&t_su_attr_denom,
	      r2_unit          =&t_unit,
              r2_sig           =&t_sig,
	      r2_htmlout       =&t_htmlout);
   %END;

PROC DATASETS LIBRARY=WORK;
   DELETE m_final;
RUN;

%GOTO finish;
%err_end:
   %PUT "FATAL JOB SPECIFICATION ERROR - JOB TERMINATED";
   %PUT "   CHECK SAS LOG for explanations";
   %GOTO last; 
%finish:
   %PUT JOB COMPLETED SUCCESSFULLY;
%last:
   %PUT Macro TABLING ended;
   TITLE;
   FOOTNOTE;
%MEND tabling;

QUIT;

*** END OF PROGRAM ***;
*** END OF PROGRAM ***;
*** END OF PROGRAM ***;
