/****************************** HEADER *********************************
Larry Bednar, US Forest Service, Portland Forestry Sciences Lab,
         Portland, OR. (503) 808-2016.
PURPOSE: These SAS statements define the main macro used to control
         execution of computational sections of the PRIME Table
         Report Application.;

$RCSfile: tabling.sas,v $
$Revision: 1.4 $
$Date: 2000/05/30 22:34:44 $
$Author: lbednar $
************************************************************************/

/******************************* CODE **********************************/

%*Set directory that tabling application files reside in;
   %LET tab_dir=\\prime2\tools\applications\tabling\program;


%*Compile data retrieval macros;
   %INCLUDE "&tab_dir\get_sp.sas";
   %*INCLUDE "&tab_dir\get_sp_r.sas";
   %*INCLUDE "&tab_dir\get_st_d.sas";
   %INCLUDE "&tab_dir\get_st_s.sas";
   %INCLUDE "&tab_dir\get_ob_s.sas";
   %*INCLUDE "&tab_dir\get_ob.sas";

%*Compile estimation macros;
   %INCLUDE "&tab_dir\double.sas";
   %INCLUDE "&tab_dir\strat.sas";
   %INCLUDE "&tab_dir\random.sas";
   %INCLUDE "&tab_dir\census.sas";

%*Compile reporting macro;
   %INCLUDE "&tab_dir\repout.sas";

%*Compile specification error checking macro;
   %*INCLUDE "&tab_dir\in_chk.sas";

%*Compile utility macros;
   %INCLUDE "&tab_dir\chg_blnk.sas";
   %INCLUDE "&tab_dir\sig_figs.sas";

%MACRO tabling(title   =PRIME population estimate,
               title2  =CA 1991 Inventory,
               method  =DOUBLE,
               est_stat=SUM,
               sp      =,
               sp_spid =,
               sp_sz   =,
               sp_ssz  =,
               st      =,
               st_spid =,
               st_stid =,
               st_sz   =,
               st_ssz1 =,
               st_ssz  =,
               su      =,
               su_spid =,
               su_stid =,
               su_suid =,
               su_rows =,
               su_cols =,
               su_attr =,
               unit    =1,
               sig     =3,
               margins =NO,
               print   =YES,
               libout  =,
               dataout =,
               htmlout =);

OPTIONS MPRINT NOSYMBOLGEN;

%*Set footnote to display application information;
%MACRO rcskval(val);
   %*This macro returns only the value from an RCS keyword/value pair;
   %LOCAL start len val2 valout;
   %LET val2  =%STR(&val);
   %LET start =%EVAL( %INDEX(&val2,: ) + 2 );
   %LET len   =%EVAL( %LENGTH(&val2) - &start );
   %LET valout=%SUBSTR(&val2,&start,&len);
   &valout
%MEND;

%LET Program=%rcskval(%STR($RCSfile: tabling.sas,v $));
%LET Version=%rcskval(%STR($Revision: 1.4 $));
%LET Coder  =%rcskval(%STR($Author: lbednar $));

FOOTNOTE
"&Program &Version - &Coder - &sysscp SAS V&sysver -(&sysdate,&systime)";

%LET method  =%UPCASE(&method);
%LET est_stat=%UPCASE(&est_stat);
%LET print   =%UPCASE(&print);
%LET margins =%UPCASE(&margins);
%PUT margins =&margins;

TITLE "&title";
TITLE2 "&title2";

PROC DATASETS LIBRARY=WORK;
    DELETE m_final;
RUN;

%*Compile and run job specification error checking macro;
   %*IF %in_chk=ERROR %THEN %GOTO err_end;

%*Execute the proper SAS computation macro for the method specified;
%&method

%*Convert final estimates to appropriate number of significant digits;
%sig_figs(data_in =work.m_final,
          chg_vars=&est_stat v_&est_stat sd_&est_stat,
          digits  =&sig)

%*Write final data to specified output data set;
%IF &libout^=   AND
    &dataout^=  %THEN
   %DO;
      DATA &libout..&dataout;
          SET m_final;
      RUN;
   %END;

%IF %UPCASE(&print)=YES %THEN
   %DO;
      %repout(rows=&su_rows,cols=&su_cols)
   %END;

%GOTO finish;
%errend:
   %PUT FATAL JOB SPECIFICATION ERROR - JOB TERMINATED;
%finish:
   %PUT JOB COMPLETED SUCCESSFULLY;
%put Macro TABLING ended;
TITLE;
FOOTNOTE;
%mend tabling;

QUIT;

*** END OF PROGRAM ***;
*** END OF PROGRAM ***;
*** END OF PROGRAM ***;
